@@ -95,14 +95,14 @@ int yyparse (void);
 
 static int yylex (void);
 
-void yyerror (const char *);
+static void yyerror (const char *);
 
 static void growbuf_by_size (int);
 
 static int match_string_literal (void);
 
 
-#line 106 "f-exp.c" /* yacc.c:339  */
+#line 106 "f-exp.c.tmp" /* yacc.c:339  */
 
 # ifndef YY_NULLPTRPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -159,7 +159,7 @@ extern int yydebug;
     BOOL_OR = 280,
     BOOL_NOT = 281,
     CHARACTER = 282,
-    VARIABLE = 283,
+    DOLLAR_VARIABLE = 283,
     ASSIGN_MODIFY = 284,
     ABOVE_COMMA = 285,
     EQUAL = 286,
@@ -200,7 +200,7 @@ extern int yydebug;
 #define BOOL_OR 280
 #define BOOL_NOT 281
 #define CHARACTER 282
-#define VARIABLE 283
+#define DOLLAR_VARIABLE 283
 #define ASSIGN_MODIFY 284
 #define ABOVE_COMMA 285
 #define EQUAL 286
@@ -244,7 +244,7 @@ union YYSTYPE
     int *ivec;
   
 
-#line 248 "f-exp.c" /* yacc.c:355  */
+#line 248 "f-exp.c.tmp" /* yacc.c:355  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -266,7 +266,7 @@ int yyparse (void);
 static int parse_number (struct parser_state *, const char *, int,
 			 int, YYSTYPE *);
 
-#line 270 "f-exp.c" /* yacc.c:358  */
+#line 270 "f-exp.c.tmp" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -571,10 +571,10 @@ static const yytype_uint16 yyrline[] =
      276,   282,   288,   292,   300,   306,   314,   318,   322,   326,
      330,   334,   338,   342,   346,   350,   354,   358,   362,   366,
      370,   374,   378,   382,   387,   391,   395,   401,   408,   419,
-     426,   429,   432,   443,   450,   458,   495,   498,   499,   543,
-     545,   547,   549,   551,   554,   556,   558,   562,   564,   569,
-     571,   573,   575,   577,   579,   581,   583,   585,   587,   589,
-     591,   593,   595,   600,   605,   612,   616
+     426,   429,   432,   443,   450,   458,   490,   493,   494,   538,
+     540,   542,   544,   546,   549,   551,   553,   557,   559,   564,
+     566,   568,   570,   572,   574,   576,   578,   580,   582,   584,
+     586,   588,   590,   595,   600,   607,   611
 };
 #endif
 
@@ -589,7 +589,7 @@ static const char *const yytname[] =
   "LOGICAL_S2_KEYWORD", "LOGICAL_S8_KEYWORD", "LOGICAL_KEYWORD",
   "REAL_KEYWORD", "REAL_S8_KEYWORD", "REAL_S16_KEYWORD",
   "COMPLEX_S8_KEYWORD", "COMPLEX_S16_KEYWORD", "COMPLEX_S32_KEYWORD",
-  "BOOL_AND", "BOOL_OR", "BOOL_NOT", "CHARACTER", "VARIABLE",
+  "BOOL_AND", "BOOL_OR", "BOOL_NOT", "CHARACTER", "DOLLAR_VARIABLE",
   "ASSIGN_MODIFY", "','", "ABOVE_COMMA", "'='", "'?'", "'|'", "'^'", "'&'",
   "EQUAL", "NOTEQUAL", "LESSTHAN", "GREATERTHAN", "LEQ", "GEQ", "LSH",
   "RSH", "'@'", "'+'", "'-'", "'*'", "'/'", "STARSTAR", "'%'", "UNARY",
@@ -1522,55 +1522,55 @@ yyreduce:
     { write_exp_elt_opcode (pstate, OP_TYPE);
 			  write_exp_elt_type (pstate, (yyvsp[0].tval));
 			  write_exp_elt_opcode (pstate, OP_TYPE); }
-#line 1527 "f-exp.c" /* yacc.c:1646  */
+#line 1527 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 5:
 #line 203 "f-exp.y" /* yacc.c:1646  */
     { }
-#line 1533 "f-exp.c" /* yacc.c:1646  */
+#line 1533 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 6:
 #line 208 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, UNOP_IND); }
-#line 1539 "f-exp.c" /* yacc.c:1646  */
+#line 1539 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 7:
 #line 212 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, UNOP_ADDR); }
-#line 1545 "f-exp.c" /* yacc.c:1646  */
+#line 1545 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 8:
 #line 216 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, UNOP_NEG); }
-#line 1551 "f-exp.c" /* yacc.c:1646  */
+#line 1551 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 9:
 #line 220 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, UNOP_LOGICAL_NOT); }
-#line 1557 "f-exp.c" /* yacc.c:1646  */
+#line 1557 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 10:
 #line 224 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, UNOP_COMPLEMENT); }
-#line 1563 "f-exp.c" /* yacc.c:1646  */
+#line 1563 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 11:
 #line 228 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, UNOP_SIZEOF); }
-#line 1569 "f-exp.c" /* yacc.c:1646  */
+#line 1569 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 12:
 #line 237 "f-exp.y" /* yacc.c:1646  */
     { start_arglist (); }
-#line 1575 "f-exp.c" /* yacc.c:1646  */
+#line 1575 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 13:
@@ -1581,25 +1581,25 @@ yyreduce:
 						 (LONGEST) end_arglist ());
 			  write_exp_elt_opcode (pstate,
 					      OP_F77_UNDETERMINED_ARGLIST); }
-#line 1586 "f-exp.c" /* yacc.c:1646  */
+#line 1586 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 15:
 #line 251 "f-exp.y" /* yacc.c:1646  */
     { arglist_len = 1; }
-#line 1592 "f-exp.c" /* yacc.c:1646  */
+#line 1592 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 16:
 #line 255 "f-exp.y" /* yacc.c:1646  */
     { arglist_len = 1; }
-#line 1598 "f-exp.c" /* yacc.c:1646  */
+#line 1598 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 17:
 #line 259 "f-exp.y" /* yacc.c:1646  */
     { arglist_len++; }
-#line 1604 "f-exp.c" /* yacc.c:1646  */
+#line 1604 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 18:
@@ -1607,7 +1607,7 @@ yyreduce:
     { write_exp_elt_opcode (pstate, OP_RANGE); 
 			  write_exp_elt_longcst (pstate, NONE_BOUND_DEFAULT);
 			  write_exp_elt_opcode (pstate, OP_RANGE); }
-#line 1612 "f-exp.c" /* yacc.c:1646  */
+#line 1612 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 19:
@@ -1615,7 +1615,7 @@ yyreduce:
     { write_exp_elt_opcode (pstate, OP_RANGE);
 			  write_exp_elt_longcst (pstate, HIGH_BOUND_DEFAULT);
 			  write_exp_elt_opcode (pstate, OP_RANGE); }
-#line 1620 "f-exp.c" /* yacc.c:1646  */
+#line 1620 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 20:
@@ -1623,7 +1623,7 @@ yyreduce:
     { write_exp_elt_opcode (pstate, OP_RANGE);
 			  write_exp_elt_longcst (pstate, LOW_BOUND_DEFAULT);
 			  write_exp_elt_opcode (pstate, OP_RANGE); }
-#line 1628 "f-exp.c" /* yacc.c:1646  */
+#line 1628 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 21:
@@ -1631,13 +1631,13 @@ yyreduce:
     { write_exp_elt_opcode (pstate, OP_RANGE);
 			  write_exp_elt_longcst (pstate, BOTH_BOUND_DEFAULT);
 			  write_exp_elt_opcode (pstate, OP_RANGE); }
-#line 1636 "f-exp.c" /* yacc.c:1646  */
+#line 1636 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 22:
 #line 289 "f-exp.y" /* yacc.c:1646  */
     { }
-#line 1642 "f-exp.c" /* yacc.c:1646  */
+#line 1642 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 23:
@@ -1647,7 +1647,7 @@ yyreduce:
 					      parse_f_type (pstate)
 					      ->builtin_complex_s16);
 			  write_exp_elt_opcode (pstate, OP_COMPLEX); }
-#line 1652 "f-exp.c" /* yacc.c:1646  */
+#line 1652 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 24:
@@ -1655,7 +1655,7 @@ yyreduce:
     { write_exp_elt_opcode (pstate, UNOP_CAST);
 			  write_exp_elt_type (pstate, (yyvsp[-2].tval));
 			  write_exp_elt_opcode (pstate, UNOP_CAST); }
-#line 1660 "f-exp.c" /* yacc.c:1646  */
+#line 1660 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 25:
@@ -1663,127 +1663,127 @@ yyreduce:
     { write_exp_elt_opcode (pstate, STRUCTOP_STRUCT);
                           write_exp_string (pstate, (yyvsp[0].sval));
                           write_exp_elt_opcode (pstate, STRUCTOP_STRUCT); }
-#line 1668 "f-exp.c" /* yacc.c:1646  */
+#line 1668 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 26:
 #line 315 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_REPEAT); }
-#line 1674 "f-exp.c" /* yacc.c:1646  */
+#line 1674 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 27:
 #line 319 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_EXP); }
-#line 1680 "f-exp.c" /* yacc.c:1646  */
+#line 1680 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 28:
 #line 323 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_MUL); }
-#line 1686 "f-exp.c" /* yacc.c:1646  */
+#line 1686 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 29:
 #line 327 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_DIV); }
-#line 1692 "f-exp.c" /* yacc.c:1646  */
+#line 1692 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 30:
 #line 331 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_ADD); }
-#line 1698 "f-exp.c" /* yacc.c:1646  */
+#line 1698 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 31:
 #line 335 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_SUB); }
-#line 1704 "f-exp.c" /* yacc.c:1646  */
+#line 1704 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 32:
 #line 339 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_LSH); }
-#line 1710 "f-exp.c" /* yacc.c:1646  */
+#line 1710 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 33:
 #line 343 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_RSH); }
-#line 1716 "f-exp.c" /* yacc.c:1646  */
+#line 1716 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 34:
 #line 347 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_EQUAL); }
-#line 1722 "f-exp.c" /* yacc.c:1646  */
+#line 1722 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 35:
 #line 351 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_NOTEQUAL); }
-#line 1728 "f-exp.c" /* yacc.c:1646  */
+#line 1728 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 36:
 #line 355 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_LEQ); }
-#line 1734 "f-exp.c" /* yacc.c:1646  */
+#line 1734 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 37:
 #line 359 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_GEQ); }
-#line 1740 "f-exp.c" /* yacc.c:1646  */
+#line 1740 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 38:
 #line 363 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_LESS); }
-#line 1746 "f-exp.c" /* yacc.c:1646  */
+#line 1746 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 39:
 #line 367 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_GTR); }
-#line 1752 "f-exp.c" /* yacc.c:1646  */
+#line 1752 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 40:
 #line 371 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_BITWISE_AND); }
-#line 1758 "f-exp.c" /* yacc.c:1646  */
+#line 1758 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 41:
 #line 375 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_BITWISE_XOR); }
-#line 1764 "f-exp.c" /* yacc.c:1646  */
+#line 1764 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 42:
 #line 379 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_BITWISE_IOR); }
-#line 1770 "f-exp.c" /* yacc.c:1646  */
+#line 1770 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 43:
 #line 383 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_LOGICAL_AND); }
-#line 1776 "f-exp.c" /* yacc.c:1646  */
+#line 1776 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 44:
 #line 388 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_LOGICAL_OR); }
-#line 1782 "f-exp.c" /* yacc.c:1646  */
+#line 1782 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 45:
 #line 392 "f-exp.y" /* yacc.c:1646  */
     { write_exp_elt_opcode (pstate, BINOP_ASSIGN); }
-#line 1788 "f-exp.c" /* yacc.c:1646  */
+#line 1788 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 46:
@@ -1791,7 +1791,7 @@ yyreduce:
     { write_exp_elt_opcode (pstate, BINOP_ASSIGN_MODIFY);
 			  write_exp_elt_opcode (pstate, (yyvsp[-1].opcode));
 			  write_exp_elt_opcode (pstate, BINOP_ASSIGN_MODIFY); }
-#line 1796 "f-exp.c" /* yacc.c:1646  */
+#line 1796 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 47:
@@ -1800,7 +1800,7 @@ yyreduce:
 			  write_exp_elt_type (pstate, (yyvsp[0].typed_val).type);
 			  write_exp_elt_longcst (pstate, (LONGEST) ((yyvsp[0].typed_val).val));
 			  write_exp_elt_opcode (pstate, OP_LONG); }
-#line 1805 "f-exp.c" /* yacc.c:1646  */
+#line 1805 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 48:
@@ -1813,7 +1813,7 @@ yyreduce:
 			  write_exp_elt_longcst (pstate,
 						 (LONGEST)val.typed_val.val);
 			  write_exp_elt_opcode (pstate, OP_LONG); }
-#line 1818 "f-exp.c" /* yacc.c:1646  */
+#line 1818 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 49:
@@ -1822,7 +1822,7 @@ yyreduce:
 			  write_exp_elt_type (pstate, (yyvsp[0].typed_val_float).type);
 			  write_exp_elt_floatcst (pstate, (yyvsp[0].typed_val_float).val);
 			  write_exp_elt_opcode (pstate, OP_FLOAT); }
-#line 1827 "f-exp.c" /* yacc.c:1646  */
+#line 1827 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 52:
@@ -1835,7 +1835,7 @@ yyreduce:
 			  write_exp_elt_longcst (pstate,
 						 (LONGEST) TYPE_LENGTH ((yyvsp[-1].tval)));
 			  write_exp_elt_opcode (pstate, OP_LONG); }
-#line 1840 "f-exp.c" /* yacc.c:1646  */
+#line 1840 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 53:
@@ -1844,7 +1844,7 @@ yyreduce:
 			  write_exp_elt_longcst (pstate, (LONGEST) (yyvsp[0].lval));
 			  write_exp_elt_opcode (pstate, OP_BOOL);
 			}
-#line 1849 "f-exp.c" /* yacc.c:1646  */
+#line 1849 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 54:
@@ -1854,7 +1854,7 @@ yyreduce:
 			  write_exp_string (pstate, (yyvsp[0].sval));
 			  write_exp_elt_opcode (pstate, OP_STRING);
 			}
-#line 1859 "f-exp.c" /* yacc.c:1646  */
+#line 1859 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 55:
@@ -1864,12 +1864,7 @@ yyreduce:
 			  if (sym.symbol)
 			    {
 			      if (symbol_read_needs_frame (sym.symbol))
-				{
-				  if (innermost_block == 0
-				      || contained_in (sym.block,
-						       innermost_block))
-				    innermost_block = sym.block;
-				}
+				innermost_block.update (sym);
 			      write_exp_elt_opcode (pstate, OP_VAR_VALUE);
 			      write_exp_elt_block (pstate, sym.block);
 			      write_exp_elt_sym (pstate, sym.symbol);
@@ -1892,11 +1887,11 @@ yyreduce:
 				       copy_name ((yyvsp[0].ssym).stoken));
 			    }
 			}
-#line 1897 "f-exp.c" /* yacc.c:1646  */
+#line 1892 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 58:
-#line 500 "f-exp.y" /* yacc.c:1646  */
+#line 495 "f-exp.y" /* yacc.c:1646  */
     {
 		  /* This is where the interesting stuff happens.  */
 		  int done = 0;
@@ -1938,173 +1933,173 @@ yyreduce:
 		      }
 		  (yyval.tval) = follow_type;
 		}
-#line 1943 "f-exp.c" /* yacc.c:1646  */
+#line 1938 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 544 "f-exp.y" /* yacc.c:1646  */
+#line 539 "f-exp.y" /* yacc.c:1646  */
     { push_type (tp_pointer); (yyval.voidval) = 0; }
-#line 1949 "f-exp.c" /* yacc.c:1646  */
+#line 1944 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 60:
-#line 546 "f-exp.y" /* yacc.c:1646  */
+#line 541 "f-exp.y" /* yacc.c:1646  */
     { push_type (tp_pointer); (yyval.voidval) = (yyvsp[0].voidval); }
-#line 1955 "f-exp.c" /* yacc.c:1646  */
+#line 1950 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 61:
-#line 548 "f-exp.y" /* yacc.c:1646  */
+#line 543 "f-exp.y" /* yacc.c:1646  */
     { push_type (tp_reference); (yyval.voidval) = 0; }
-#line 1961 "f-exp.c" /* yacc.c:1646  */
+#line 1956 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 62:
-#line 550 "f-exp.y" /* yacc.c:1646  */
+#line 545 "f-exp.y" /* yacc.c:1646  */
     { push_type (tp_reference); (yyval.voidval) = (yyvsp[0].voidval); }
-#line 1967 "f-exp.c" /* yacc.c:1646  */
+#line 1962 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 64:
-#line 555 "f-exp.y" /* yacc.c:1646  */
+#line 550 "f-exp.y" /* yacc.c:1646  */
     { (yyval.voidval) = (yyvsp[-1].voidval); }
-#line 1973 "f-exp.c" /* yacc.c:1646  */
+#line 1968 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 65:
-#line 557 "f-exp.y" /* yacc.c:1646  */
+#line 552 "f-exp.y" /* yacc.c:1646  */
     { push_type (tp_function); }
-#line 1979 "f-exp.c" /* yacc.c:1646  */
+#line 1974 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 66:
-#line 559 "f-exp.y" /* yacc.c:1646  */
+#line 554 "f-exp.y" /* yacc.c:1646  */
     { push_type (tp_function); }
-#line 1985 "f-exp.c" /* yacc.c:1646  */
+#line 1980 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 67:
-#line 563 "f-exp.y" /* yacc.c:1646  */
+#line 558 "f-exp.y" /* yacc.c:1646  */
     { (yyval.voidval) = 0; }
-#line 1991 "f-exp.c" /* yacc.c:1646  */
+#line 1986 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 68:
-#line 565 "f-exp.y" /* yacc.c:1646  */
+#line 560 "f-exp.y" /* yacc.c:1646  */
     { xfree ((yyvsp[-1].tvec)); (yyval.voidval) = 0; }
-#line 1997 "f-exp.c" /* yacc.c:1646  */
+#line 1992 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 69:
-#line 570 "f-exp.y" /* yacc.c:1646  */
+#line 565 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = (yyvsp[0].tsym).type; }
-#line 2003 "f-exp.c" /* yacc.c:1646  */
+#line 1998 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 70:
-#line 572 "f-exp.y" /* yacc.c:1646  */
+#line 567 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_integer; }
-#line 2009 "f-exp.c" /* yacc.c:1646  */
+#line 2004 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 71:
-#line 574 "f-exp.y" /* yacc.c:1646  */
+#line 569 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_integer_s2; }
-#line 2015 "f-exp.c" /* yacc.c:1646  */
+#line 2010 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 72:
-#line 576 "f-exp.y" /* yacc.c:1646  */
+#line 571 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_character; }
-#line 2021 "f-exp.c" /* yacc.c:1646  */
+#line 2016 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 73:
-#line 578 "f-exp.y" /* yacc.c:1646  */
+#line 573 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_logical_s8; }
-#line 2027 "f-exp.c" /* yacc.c:1646  */
+#line 2022 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 74:
-#line 580 "f-exp.y" /* yacc.c:1646  */
+#line 575 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_logical; }
-#line 2033 "f-exp.c" /* yacc.c:1646  */
+#line 2028 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 75:
-#line 582 "f-exp.y" /* yacc.c:1646  */
+#line 577 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_logical_s2; }
-#line 2039 "f-exp.c" /* yacc.c:1646  */
+#line 2034 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 76:
-#line 584 "f-exp.y" /* yacc.c:1646  */
+#line 579 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_logical_s1; }
-#line 2045 "f-exp.c" /* yacc.c:1646  */
+#line 2040 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 77:
-#line 586 "f-exp.y" /* yacc.c:1646  */
+#line 581 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_real; }
-#line 2051 "f-exp.c" /* yacc.c:1646  */
+#line 2046 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 78:
-#line 588 "f-exp.y" /* yacc.c:1646  */
+#line 583 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_real_s8; }
-#line 2057 "f-exp.c" /* yacc.c:1646  */
+#line 2052 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 79:
-#line 590 "f-exp.y" /* yacc.c:1646  */
+#line 585 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_real_s16; }
-#line 2063 "f-exp.c" /* yacc.c:1646  */
+#line 2058 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 80:
-#line 592 "f-exp.y" /* yacc.c:1646  */
+#line 587 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_complex_s8; }
-#line 2069 "f-exp.c" /* yacc.c:1646  */
+#line 2064 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 81:
-#line 594 "f-exp.y" /* yacc.c:1646  */
+#line 589 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_complex_s16; }
-#line 2075 "f-exp.c" /* yacc.c:1646  */
+#line 2070 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 82:
-#line 596 "f-exp.y" /* yacc.c:1646  */
+#line 591 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tval) = parse_f_type (pstate)->builtin_complex_s32; }
-#line 2081 "f-exp.c" /* yacc.c:1646  */
+#line 2076 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 83:
-#line 601 "f-exp.y" /* yacc.c:1646  */
+#line 596 "f-exp.y" /* yacc.c:1646  */
     { (yyval.tvec) = (struct type **) xmalloc (sizeof (struct type *) * 2);
 		  (yyval.ivec)[0] = 1;	/* Number of types in vector */
 		  (yyval.tvec)[1] = (yyvsp[0].tval);
 		}
-#line 2090 "f-exp.c" /* yacc.c:1646  */
+#line 2085 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 84:
-#line 606 "f-exp.y" /* yacc.c:1646  */
+#line 601 "f-exp.y" /* yacc.c:1646  */
     { int len = sizeof (struct type *) * (++((yyvsp[-2].ivec)[0]) + 1);
 		  (yyval.tvec) = (struct type **) xrealloc ((char *) (yyvsp[-2].tvec), len);
 		  (yyval.tvec)[(yyval.ivec)[0]] = (yyvsp[0].tval);
 		}
-#line 2099 "f-exp.c" /* yacc.c:1646  */
+#line 2094 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
   case 85:
-#line 613 "f-exp.y" /* yacc.c:1646  */
+#line 608 "f-exp.y" /* yacc.c:1646  */
     {  (yyval.sval) = (yyvsp[0].ssym).stoken; }
-#line 2105 "f-exp.c" /* yacc.c:1646  */
+#line 2100 "f-exp.c.tmp" /* yacc.c:1646  */
     break;
 
 
-#line 2109 "f-exp.c" /* yacc.c:1646  */
+#line 2104 "f-exp.c.tmp" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2332,7 +2327,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 626 "f-exp.y" /* yacc.c:1906  */
+#line 621 "f-exp.y" /* yacc.c:1906  */
 
 
 /* Take care of parsing a number (anything that starts with a digit).
@@ -2638,7 +2633,7 @@ yylex (void)
 {
   int c;
   int namelen;
-  unsigned int i,token;
+  unsigned int token;
   const char *tokstart;
   
  retry:
@@ -2652,7 +2647,7 @@ yylex (void)
   
   if (*lexptr == '.')
     { 
-      for (i = 0; boolean_values[i].name != NULL; i++)
+      for (int i = 0; boolean_values[i].name != NULL; i++)
 	{
 	  if (strncmp (tokstart, boolean_values[i].name,
 		       strlen (boolean_values[i].name)) == 0)
@@ -2666,7 +2661,7 @@ yylex (void)
   
   /* See if it is a special .foo. operator.  */
   
-  for (i = 0; dot_ops[i].oper != NULL; i++)
+  for (int i = 0; dot_ops[i].oper != NULL; i++)
     if (strncmp (tokstart, dot_ops[i].oper,
 		 strlen (dot_ops[i].oper)) == 0)
       {
@@ -2723,7 +2718,7 @@ yylex (void)
       /* Might be a floating point number.  */
       if (lexptr[1] < '0' || lexptr[1] > '9')
 	goto symbol;		/* Nope, must be a symbol.  */
-      /* FALL THRU into number case.  */
+      /* FALL THRU.  */
       
     case '0':
     case '1':
@@ -2835,7 +2830,7 @@ yylex (void)
   
   /* Catch specific keywords.  */
   
-  for (i = 0; f77_keywords[i].oper != NULL; i++)
+  for (int i = 0; f77_keywords[i].oper != NULL; i++)
     if (strlen (f77_keywords[i].oper) == namelen
 	&& strncmp (tokstart, f77_keywords[i].oper, namelen) == 0)
       {
@@ -2850,7 +2845,7 @@ yylex (void)
   if (*tokstart == '$')
     {
       write_dollar_variable (pstate, yylval.sval);
-      return VARIABLE;
+      return DOLLAR_VARIABLE;
     }
   
   /* Use token-type TYPENAME for symbols that happen to be defined
@@ -2866,10 +2861,9 @@ yylex (void)
       VAR_DOMAIN,
       MODULE_DOMAIN
     };
-    int i;
     int hextype;
 
-    for (i = 0; i < ARRAY_SIZE (lookup_domains); ++i)
+    for (int i = 0; i < ARRAY_SIZE (lookup_domains); ++i)
       {
 	/* Initialize this in case we *don't* use it in this call; that
 	   way we can refer to it unconditionally below.  */
@@ -2931,11 +2925,11 @@ f_parse (struct parser_state *par_state)
   return yyparse ();
 }
 
-void
+static void
 yyerror (const char *msg)
 {
   if (prev_lexptr)
     lexptr = prev_lexptr;
 
-  error (_("A %s in expression, near `%s'."), (msg ? msg : "error"), lexptr);
+  error (_("A %s in expression, near `%s'."), msg, lexptr);
 }
